@@ -84,18 +84,17 @@ format = 1
 
 */
 
-
 /** @page syntax Syntax of Highlighting Description Files
 
 @section syntax_introduction Introduction
 
 The syntax highlighting of libt3highlight is highly configurable. In the
 following sections the syntax of the highlighting description files is
-detailed. libt3highlight uses the <a href="http://pcre.org">PCRE library</a>
-for regular expression matching. See the documentation of the PCRE library
-(either the local pcrepattern manpage, or the online documentation) for details
-on the regular expression syntax. All features of the PCRE library are available,
-with the exception of the @\G assertion.
+detailed. libt3highlight uses the <a href="http://pcre.org">PCRE2 library</a>
+for regular expression matching. See the documentation of the PCRE2 library
+(either the local pcre2pattern manpage, or the online documentation) for
+details on the regular expression syntax. All features of the PCRE2 library are
+available, with the exception of the @\G assertion.
 
 libt3highlight uses the libt3config library for storing the highlighting
 description files. For the most part, the syntax of the files will be
@@ -239,10 +238,11 @@ Shell language:
 }
 @endverbatim
 
-This uses the PCRE named sub-pattern syntax, as described in the pcrepattern(3)
-man page. Note that this is a relatively expensive operation, because the
-@c end pattern has to be created on the fly. It is therefore inadvisable to use
-this for patterns which can also be written using fixed patterns.
+This uses the PCRE2 named sub-pattern syntax, as described in the
+pcre2pattern(3) man page. Note that this is a relatively expensive operation,
+because the @c end pattern has to be created on the fly. It is therefore
+inadvisable to use this for patterns which can also be written using fixed
+patterns.
 
 @subsubsection state_exit State Exit
 
@@ -413,8 +413,8 @@ the line. This state is then exited when the new line is started:
 By entering a new sub state, we avoid matching the @c end pattern. Thus the
 string is continued on the next line.
 
-@note In versions before 0.2.0 a single pattern could be written using the PCRE
-@\G assertion. However, due to a change in the matching process for
+@note In versions before 0.2.0 a single pattern could be written using the
+PCRE2 @\G assertion. However, due to a change in the matching process for
 optimization purposes, this assertion will be true at every point in the input.
 Therefore, it is no longer usable.
 
@@ -472,7 +472,8 @@ documents {
   # been omitted for brevity.
   separate-css {
     description = "HTML 4.01 strict with style sheet reference (use css tag)"
-    header = '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">\n<html><head>\n' +
+    header = '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN"
+"http://www.w3.org/TR/html4/strict.dtd">\n<html><head>\n' +
       '<meta http-equiv="Content-Type" content="text/html; charset=%{charset}">' +
       '<!--Generated by t3highlight-->\n' +
       '<link href="%{css}" rel="stylesheet" type="text/css">' +
